﻿Imports System.Drawing.Text
Imports System.IO

Public Class Form1

    Private fonts As InstalledFontCollection
    Private favoriteFonts As New List(Of String)

    Private Sub Form1_Load(sender As Object, e As EventArgs) Handles MyBase.Load
        LoadFonts()
        InitializeFontStyles()
        NumericUpDown1.Minimum = 8
        NumericUpDown1.Maximum = 72
        NumericUpDown1.Value = 16 ' Default font size
        Label2.Text = String.Empty
        LoadFavoriteFonts() ' Load favorite fonts if any
    End Sub

    Private Sub LoadFonts()
        ListBox1.Items.Clear()
        fonts = New InstalledFontCollection()

        ' Loop through the font families and add them to the list box
        For Each fontFamily In fonts.Families
            If CheckBoxRegular.Checked AndAlso fontFamily.IsStyleAvailable(FontStyle.Regular) Then
                ListBox1.Items.Add(fontFamily.Name)
            End If
            If CheckBoxBold.Checked AndAlso fontFamily.IsStyleAvailable(FontStyle.Bold) Then
                ListBox1.Items.Add(fontFamily.Name)
            End If
            If CheckBoxItalic.Checked AndAlso fontFamily.IsStyleAvailable(FontStyle.Italic) Then
                ListBox1.Items.Add(fontFamily.Name)
            End If
        Next
    End Sub

    Private Sub InitializeFontStyles()
        ComboBox1.Items.Add("Regular")
        ComboBox1.Items.Add("Bold")
        ComboBox1.Items.Add("Italic")
        ComboBox1.SelectedIndex = 0 ' Default to Regular
    End Sub

    Private Sub Button1_Click(sender As Object, e As EventArgs) Handles Button1.Click
        FilterFonts(TextBox1.Text)
    End Sub

    Private Sub FilterFonts(searchTerm As String)
        ListBox1.Items.Clear()
        For Each fontFamily In fonts.Families
            If fontFamily.Name.ToLower().Contains(searchTerm.ToLower()) Then
                ListBox1.Items.Add(fontFamily.Name)
            End If
        Next
    End Sub

    Private Sub ListBox1_SelectedIndexChanged(sender As Object, e As EventArgs) Handles ListBox1.SelectedIndexChanged
        UpdateFontPreview()
    End Sub

    Private Sub UpdateFontPreview()
        Dim selectedFont As String = ListBox1.SelectedItem?.ToString()
        Dim fontStyle As FontStyle = FontStyle.Regular

        If ComboBox1.SelectedItem IsNot Nothing Then
            Select Case ComboBox1.SelectedItem.ToString()
                Case "Bold"
                    fontStyle = FontStyle.Bold
                Case "Italic"
                    fontStyle = FontStyle.Italic
            End Select
        End If

        If Not String.IsNullOrEmpty(selectedFont) Then
            Label1.Font = New Font(selectedFont, CInt(NumericUpDown1.Value), fontStyle)
            ''Label1.ForeColor = Color.Black ' Default color
            Label1.Text = "The quick brown fox jumps over the lazy dog."
            ' Display font characteristics
            Label2.Text = $"Font: {selectedFont}, Style: {fontStyle}, Size: {NumericUpDown1.Value}"
            TextBox2.Font = Label1.Font

            LabelNormal.Font = New Font(selectedFont, 16, FontStyle.Regular)
            LabelBold.Font = New Font(selectedFont, 16, FontStyle.Bold)
            LabelItalic.Font = New Font(selectedFont, 16, FontStyle.Italic)

            LabelNormal.Text = "Normal Style Sample"
            LabelBold.Text = "Bold Style Sample"
            LabelItalic.Text = "Italic Style Sample"
        Else
            Label1.Font = New Font("Arial", 16)
            Label1.Text = String.Empty
            Label2.Text = String.Empty

            LabelNormal.Text = ""
            LabelBold.Text = ""
            LabelItalic.Text = ""
        End If
    End Sub

    Private Sub Button2_Click(sender As Object, e As EventArgs) Handles Button2.Click
        SaveFontsToFile()
    End Sub

    Private Sub SaveFontsToFile()
        Dim saveFileDialog As New SaveFileDialog()
        saveFileDialog.Filter = "Text Files (*.txt)|*.txt|All Files (*.*)|*.*"
        saveFileDialog.Title = "Save Font List"

        If saveFileDialog.ShowDialog() = DialogResult.OK Then
            Using writer As New StreamWriter(saveFileDialog.FileName)
                For Each item In ListBox1.Items
                    writer.WriteLine(item.ToString())
                Next
            End Using
            MessageBox.Show("Font list saved successfully!", "Info", MessageBoxButtons.OK, MessageBoxIcon.Information)
        End If
    End Sub

    Private Sub Button3_Click(sender As Object, e As EventArgs) Handles Button3.Click
        TextBox1.Clear()
        LoadFonts() ' Reload all fonts
    End Sub

    Private Sub Button4_Click(sender As Object, e As EventArgs) Handles Button4.Click
        Dim sortedList As List(Of String) = ListBox1.Items.Cast(Of String)().OrderBy(Function(f) f).ToList()
        ListBox1.Items.Clear()
        For Each item In sortedList
            ListBox1.Items.Add(item)
        Next
    End Sub

    Private Sub Button5_Click(sender As Object, e As EventArgs) Handles Button5.Click
        If ListBox1.SelectedItems.Count > 0 Then
            Dim selectedFonts As New List(Of String)

            ' Iterate through selected items and add their names to the list
            For Each item As String In ListBox1.SelectedItems
                selectedFonts.Add(item)
            Next

            ' Join the selected font names into a single string (you can choose a separator)
            Dim fontsToCopy As String = String.Join(Environment.NewLine, selectedFonts)

            ' Copy the combined string to the clipboard
            Clipboard.SetText(fontsToCopy)
            MessageBox.Show("Font names copied to clipboard!", "Info", MessageBoxButtons.OK, MessageBoxIcon.Information)
        Else
            MessageBox.Show("Please select at least one font to copy.", "Warning", MessageBoxButtons.OK, MessageBoxIcon.Warning)
        End If
    End Sub

    Private Sub NumericUpDown1_ValueChanged(sender As Object, e As EventArgs) Handles NumericUpDown1.ValueChanged
        UpdateFontPreview() ' Update preview when size changes
    End Sub

    ' New Feature: Select Color for Preview Text
    Private Sub ButtonColorPicker_Click(sender As Object, e As EventArgs) Handles ButtonColorPicker.Click
        Dim colorDialog As New ColorDialog()
        If colorDialog.ShowDialog() = DialogResult.OK Then
            Label1.ForeColor = colorDialog.Color
        End If
    End Sub

    ' New Feature: Reset Preview
    Private Sub Button6_Click(sender As Object, e As EventArgs) Handles Button6.Click
        ListBox1.ClearSelected()
        Label1.Font = New Font("Arial", 16)
        Label1.ForeColor = Color.Black
        Label1.Text = "The quick brown fox jumps over the lazy dog."
        Label2.Text = "Font: Arial, Style: Regular, Size: 16"
    End Sub

    ' New Feature: Save Selected Font Information
    Private Sub Button7_Click(sender As Object, e As EventArgs) Handles Button7.Click
        If ListBox1.SelectedItem IsNot Nothing Then
            Dim selectedFontInfo = $"Font: {ListBox1.SelectedItem.ToString()}, Style: {ComboBox1.SelectedItem.ToString()}, Size: {NumericUpDown1.Value}"
            Dim saveFileDialog As New SaveFileDialog()
            saveFileDialog.Filter = "Text Files (*.txt)|*.txt|All Files (*.*)|*.*"
            saveFileDialog.Title = "Save Font Information"

            If saveFileDialog.ShowDialog() = DialogResult.OK Then
                File.WriteAllText(saveFileDialog.FileName, selectedFontInfo)
                MessageBox.Show("Font information saved successfully!", "Info", MessageBoxButtons.OK, MessageBoxIcon.Information)
            End If
        End If
    End Sub

    ' New Feature: Batch Preview
    Private Sub ButtonBatchPreview_Click(sender As Object, e As EventArgs) Handles ButtonBatchPreview.Click
        If ListBox1.SelectedItems.Count > 0 Then
            Dim batchPreviewForm As New Form()
            batchPreviewForm.Text = "Batch Font Preview"
            Dim flowLayoutPanel As New FlowLayoutPanel() With {
                .Dock = DockStyle.Fill,
                .AutoScroll = True
            }

            For Each selectedItem In ListBox1.SelectedItems
                Dim fontName As String = selectedItem.ToString()
                Dim label As New Label() With {
                    .Text = "The quick brown fox jumps over the lazy dog.",
                    .Font = New Font(fontName, 16), ' Default size
                    .AutoSize = True
                }
                flowLayoutPanel.Controls.Add(label)
            Next

            batchPreviewForm.Controls.Add(flowLayoutPanel)
            batchPreviewForm.ClientSize = New Size(400, 300)
            batchPreviewForm.ShowDialog()
        Else
            MessageBox.Show("Please select one or more fonts for a batch preview.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End If
    End Sub

    Private Sub ComboBox1_SelectedIndexChanged(sender As Object, e As EventArgs) Handles ComboBox1.SelectedIndexChanged
        UpdateFontPreview()
    End Sub

    Private Sub TextBox1_TextChanged(sender As Object, e As EventArgs) Handles TextBox1.TextChanged
        FilterFonts(TextBox1.Text)
    End Sub

    Private Sub ButtonExport_Click(sender As Object, e As EventArgs) Handles ButtonExport.Click
        Dim saveFileDialog As New SaveFileDialog()
        saveFileDialog.Filter = "PNG Image|*.png"
        saveFileDialog.Title = "Save Font Preview as Image"

        If saveFileDialog.ShowDialog() = DialogResult.OK Then
            Using bitmap As New Bitmap(1209, 100) ' Adjust size as needed
                Using graphics As Graphics = Graphics.FromImage(bitmap)
                    graphics.Clear(Color.White)
                    Dim font As Font = Label1.Font
                    graphics.DrawString(Label1.Text, font, Brushes.Black, New PointF(10, 30))
                End Using
                bitmap.Save(saveFileDialog.FileName, System.Drawing.Imaging.ImageFormat.Png)
            End Using
            MessageBox.Show("Font preview saved as image successfully!", "Info", MessageBoxButtons.OK, MessageBoxIcon.Information)
        End If
    End Sub

    Private Sub LoadFavoriteFonts()
        ListBoxFavorites.Items.Clear() ' Clear the current items in the Favorites ListBox
        For Each font As String In favoriteFonts
            ListBoxFavorites.Items.Add(font) ' Add each favorite font to the ListBox
        Next
    End Sub

    Private Sub ButtonFavorite_Click(sender As Object, e As EventArgs) Handles ButtonFavorite.Click
        Dim selectedFont As String = ListBox1.SelectedItem?.ToString()

        If String.IsNullOrEmpty(selectedFont) Then
            MessageBox.Show("Please select a font first.", "Info", MessageBoxButtons.OK, MessageBoxIcon.Information)
            Return
        End If

        If favoriteFonts.Contains(selectedFont) Then
            favoriteFonts.Remove(selectedFont)
            MessageBox.Show($"{selectedFont} has been removed from favorites.", "Info", MessageBoxButtons.OK, MessageBoxIcon.Information)
        Else
            favoriteFonts.Add(selectedFont)
            MessageBox.Show($"{selectedFont} has been added to favorites.", "Info", MessageBoxButtons.OK, MessageBoxIcon.Information)
        End If

        LoadFavoriteFonts() ' Update the favorites list box
    End Sub

End Class
